@@ -1,18 +1,19 @@
 #' @name stockRecruitment
 #' 
-#' @title Creates a function for a specific parameterization of a common stock-recruitment model .
+#' @title Creates a function for a specific parameterization of a common stock-recruitment function .
 #'
-#' @description Creates a function for a specific parameterization of a \dQuote{Beverton-Holt}, \dQuote{Ricker},  \dQuote{Shepherd}, or \dQuote{Saila-Lorda} stock-recruitment model.  Use \code{srModels()} to see the equations of each model.
+#' @description Creates a function for a specific parameterization of a \dQuote{Beverton-Holt}, \dQuote{Ricker},  \dQuote{Shepherd}, or \dQuote{Saila-Lorda} stock-recruitment function.  Use \code{srFunShow()} to see the equations of each function.
 #'
-#' @param type A string that indicates the type of stock-recruitment model.
-#' @param param A single numeric that indicates the parameterization of the stock-recruitment model type.
+#' @param type A string that indicates the type of stock-recruitment function.
+#' @param param A single numeric that indicates the parameterization of the stock-recruitment function.
 #' @param simple A logical that indicates whether the user should be allowed to send all parameter values in the first parameter argument (\code{=FALSE}; default) or whether all individual parameters must be specified (\code{=TRUE}).
-#' @param msg A logical that indicates whether a message about the model and parameter definitions should be output (\code{=TRUE}) or not (\code{=FALSE}; default).
+#' @param msg A logical that indicates whether a message about the function and parameter definitions should be output (\code{=TRUE}) or not (\code{=FALSE}; default).
+#' @param plot A logical that indicates whether the growth function expression should be shown as an equation in a simple plot.
 #' @param \dots Not implemented.
 #'
-#' @return \code{srFuns} returns a function that can be used to predict recruitment given a vector of stock sizes and values for the model parameters.  The result should be saved to an object that can then be used as a function name.  When the resulting function is used, the parameters are ordered as shown when the definitions of the parameters are printed after the function is called (assuming that \code{msg=TRUE}).  The values for both/all parameters can be included as a vector of length two/three in the first parameter argument.  If \code{simple=FALSE} then the values for all parameters can be included as a vector in the first parameter argument.  If \code{simple=TRUE} then all parameters must be declared individually in each function.  The resulting function is somewhat easier to read when \code{simple=TRUE}.
+#' @return \code{srFuns} returns a function that can be used to predict recruitment given a vector of stock sizes and values for the function parameters.  The result should be saved to an object that can then be used as a function name.  When the resulting function is used, the parameters are ordered as shown when the definitions of the parameters are printed after the function is called (assuming that \code{msg=TRUE}).  The values for both/all parameters can be included as a vector of length two/three in the first parameter argument.  If \code{simple=FALSE} then the values for all parameters can be included as a vector in the first parameter argument.  If \code{simple=TRUE} then all parameters must be declared individually in each function.  The resulting function is somewhat easier to read when \code{simple=TRUE}.
 #' 
-#' \code{srModels} returns a graphic that uses \code{\link{plotmath}} to show the model formulae in a pretty format.
+#' \code{srFunShow} returns an expression that can be use with \code{\link{plotmath}} to show the function equation in a pretty format.  See examples.
 #'
 #' @author Derek H. Ogle, \email{derek@@derekogle.com}, thanks to Gabor Grothendieck for a hint about using \code{get()}.
 #'
@@ -38,9 +39,6 @@
 #' 
 #' @examples
 #' ## See the formulae
-#' \dontrun{windows(6,5)}
-#' srModels()
-#' 
 #' ## Simple Examples
 #' # show what a message looks like with the function definition
 #' srFuns("Ricker",msg=TRUE)
@@ -64,7 +62,7 @@
 #' ( sl1 <- srFuns("SailaLorda") )
 #' lines(sl1(stock,a=0.5,b=0.005,c=1.05)~stock,lwd=2,col="salmon")
 #' 
-#' ## Examples of fitting stock-recruitment models
+#' ## Examples of fitting stock-recruitment functions
 #' data(CodNorwegian)
 #'
 #' # Fitting the Beverton-Holt #1 parameterization with multiplicative errors
@@ -80,7 +78,33 @@
 #' fit2 <- nls(log(recruits)~log(r3(stock,a,Rp)),data=CodNorwegian,start=r3s)
 #' summary(fit2,correlation=TRUE)
 #' curve(r3(x,a=coef(fit2)[1],Rp=coef(fit2)[2]),from=0,to=200,col="blue",lwd=3,add=TRUE)
+#'
+#' #############################################################################
+#' ## Create expressions of the functions
+#' #############################################################################
+#' # Simple example
+#' srFunShow()
+#' srFunShow(plot=TRUE)
+#' srFunShow("BevertonHolt",1,plot=TRUE)
 #' 
+#' # Get and save the expression
+#' ( tmp <- srFunShow("BevertonHolt",1) )
+#' # Use expression as title on a plot
+#' plot(bh1(stock,a=0.5,b=0.01)~stock,type="l",ylim=c(0,50),
+#'      ylab="Recruits",xlab="Spawners",main=tmp)
+#' # Put expression in the main plot
+#' text(800,10,tmp)
+#' # Put multiple expressions on a plot
+#' op <- par(mar=c(0.1,0.1,0.1,0.1))
+#' plot(0,type="n",xlab="",ylab="",xlim=c(0,1),ylim=c(0,3),xaxt="n",yaxt="n")
+#' text(0,2.5,"Beverton-Holt #1:",pos=4)
+#' text(0.5,2.5,srFunShow("BevertonHolt",1))
+#' text(0,1.5,"Ricker #2:",pos=4)
+#' text(0.5,1.5,srFunShow("Ricker",2))
+#' text(0,0.5,"Shepherd:",pos=4)
+#' text(0.5,0.5,srFunShow("Shepherd"))
+#' par(op)
+
 NULL
 
 #' @rdname stockRecruitment
@@ -147,7 +171,7 @@ srFuns <- function(type=c("BevertonHolt","Ricker","Shepherd","SailaLorda","indep
     if (!param %in% 1:3) stop("'param' must be in 1:3 when type='Ricker'.",call.=FALSE)
     type <- paste0(type,param)
   } else {
-    if (param>1) warning("Only 'param=1' is used with '",type,"' model.",call.=FALSE)
+    if (param>1) warning("Only 'param=1' is used with '",type,"' function.",call.=FALSE)
     param <- 1
   }
   
@@ -155,58 +179,58 @@ srFuns <- function(type=c("BevertonHolt","Ricker","Shepherd","SailaLorda","indep
   if (msg) {
     switch(type,
       BevertonHolt1={
-        message("You have chosen the first parameterization of the 'Beverton-Holt' S-R model.\n\n",
+        message("You have chosen the first parameterization of the 'Beverton-Holt' S-R function.\n\n",
                 "  E[R|S] = a*S/(1+b*S)\n\n",
                 "  where a = the density-independent slope near S=0.\n",
                 "        b = density-dependent parameter.\n")
       },
       BevertonHolt2={
-        message("You have chosen the second parameterization of the 'Beverton-Holt' S-R model.\n\n",
+        message("You have chosen the second parameterization of the 'Beverton-Holt' S-R function.\n\n",
                 "  E[R|S] = a*S/(1+a*(S/Rp))\n\n",
                 "  where a = the density-independent slope near S=0.\n",
                 "       Rp = peak recruitment at the asymptote.\n")
       },
       BevertonHolt3={
-        message("You have chosen the third parameterization of the 'Beverton-Holt' S-R model.\n\n",
+        message("You have chosen the third parameterization of the 'Beverton-Holt' S-R function.\n\n",
                 "  E[R|S] = S/(a+b*S)\n")
       },
       BevertonHolt4={
-        message("You have chosen the fourth parameterization of the 'Beverton-Holt' S-R model.\n\n",
+        message("You have chosen the fourth parameterization of the 'Beverton-Holt' S-R function.\n\n",
                 "  E[R|S] = S/(a+S/Rp)\n\n",
                 "  where Rp = peak recruitment at the asymptote.\n")
       },
       Ricker1={
-        message("You have chosen the first parameterization of the 'Ricker' S-R model.\n\n",
+        message("You have chosen the first parameterization of the 'Ricker' S-R function.\n\n",
                 "  E[R|S] = a*S*exp(-b*S)\n\n",
                 "  where a = the density-independent slope near S=0.\n",
                 "        b = density-dependent parameter.\n")
       },
       Ricker2={
-        message("You have chosen the second parameterization of the 'Ricker' S-R model.\n\n",
+        message("You have chosen the second parameterization of the 'Ricker' S-R function.\n\n",
                 "  E[R|S] = S*exp(a-b*S)\n\n",
                 "  where b = density-dependent parameter.\n")
       },
       Ricker3={
-        message("You have chosen the third parameterization of the 'Ricker' S-R model.\n\n",
+        message("You have chosen the third parameterization of the 'Ricker' S-R function.\n\n",
                 "  E[R|S] = a*S*exp(-a*S/(e*Rp))\n\n",
                 "  where a = the density-independent slope near S=0.\n",
                 "       Rp = peak level of recruitment.\n")
       },
       Shepherd={
-        message("You have chosen the 'Shepherd' S-R model.\n\n",
+        message("You have chosen the 'Shepherd' S-R function.\n\n",
                 "  E[R|S] = a*S/(1+(b*S)^c)\n\n",
                 "  where a = the density-independent slope near S=0.\n",
                 "        b = density-dependent parameter.\n",
                 "        c = shape parameter.\n")
       },
       SailaLorda={
-        message("You have chosen the 'Saila-Lorda' S-R model.\n\n",
+        message("You have chosen the 'Saila-Lorda' S-R function.\n\n",
                 "  E[R|S] = a*(S^c)*exp(-b*S)\n\n",
                 "  where a = the density-independent slope near S=0.\n",
                 "        b = density-dependent parameter.\n",
                 "        c = shape parameter.\n")      },
       independence={
-        message("You have chosen the 'density-independent' S-R model.\n\n",
+        message("You have chosen the 'density-independent' S-R function.\n\n",
                 "  E[R|S] = a*S\n\n",
                 "  where a = the density-independent slope near S=0.\n")      }
     )  # end type switch
@@ -217,34 +241,58 @@ srFuns <- function(type=c("BevertonHolt","Ricker","Shepherd","SailaLorda","indep
 
 #' @rdname stockRecruitment
 #' @export
-srModels <- function(...) {
-  op <- graphics::par(mar=c(0,0,2,0))
-  graphics::plot(1,type="n",ylim=c(0,6),xlim=c(0,1),xaxt="n",yaxt="n",xlab="",ylab="",bty="n",
-       main="FSA Stock-Recruit Model Parametrizations",...)
-  iSRModels("BH1",0,5.5)
-  iSRModels("BH2",0,4.25)
-  iSRModels("BH3",0,3)
-  iSRModels("BH4",0,1.75)
-  
-  iSRModels("R1",0.55,5.5)
-  iSRModels("R2",0.55,4.25)
-  iSRModels("R3",0.55,3)
-  iSRModels("Shepherd",0.55,1.75)
-  iSRModels("SailaLorda",0.55,0.5)
-  graphics::par(op)
+srFunShow <- function(type=c("BevertonHolt","Ricker","Shepherd","SailaLorda"),
+                      param=1,plot=FALSE,...) {
+  type <- match.arg(type)
+  if (!is.numeric(param)) stop("'param' must be numeric.",call.=FALSE)
+  switch(type,
+         BevertonHolt = { expr <- iSRS_BH(param) },
+         Ricker = { expr <- iSRS_RICKER(param) },
+         Shepherd = { expr <- iSRS_SHEPHERD() },
+         SailaLorda = { expr <- iSRS_SL() })
+  if (plot) {
+    op <- graphics::par(mar=c(0.1,0.1,0.1,0.1))
+    graphics::plot(0,type="n",ylim=c(0,1),xlim=c(0,1),xaxt="n",yaxt="n",
+                   xlab="",ylab="",bty="n",...)
+    graphics::text(0.5,0.5,expr,...)
+    graphics::par(op)
+  }
+  expr
 }
 
-## Internal function for plotting the different models.  Send positions in xpos and ypos.
-iSRModels <- function(which,xpos,ypos) {
-  switch(which,
-         BH1={graphics::text(xpos,ypos,expression(plain("BevertonHolt #1: ")~~~R==frac(aS,1+bS)),pos=4)},
-         BH2={graphics::text(xpos,ypos,expression(plain("BevertonHolt #2: ")~~~R==frac(aS,1+a*~frac(S,R[p]))),pos=4)},
-         BH3={graphics::text(xpos,ypos,expression(plain("BevertonHolt #3: ")~~~R==frac(S,tilde(a)+tilde(b)*S)),pos=4)},
-         BH4={graphics::text(xpos,ypos,expression(plain("BevertonHolt #4: ")~~~R==frac(S,tilde(a)+frac(S,R[p]))),pos=4)},
-         R1 ={graphics::text(xpos,ypos,expression(plain("Ricker #1: ")~~~R==aSe^{-bS}),pos=4)},
-         R2 ={graphics::text(xpos,ypos,expression(plain("Ricker #2: ")~~~R==Se^{tilde(a)-bS}),pos=4)},
-         R3 ={graphics::text(xpos,ypos,expression(plain("Ricker #3: ")~~~R==aSe^{-a*~frac(S,R[p]*~e)}),pos=4)},
-         Shepherd={graphics::text(xpos,ypos,expression(plain("Shepherd: ")~~~R==frac(aS,1+(bS)^{c})),pos=4)},
-         SailaLorda={graphics::text(xpos,ypos,expression(plain("Saila-Lorda: ")~~~R==aS^{c}*e^{-bS}),pos=4)}
-  )
-}
\ No newline at end of file
+################################################################################
+## Internal functions for growth function expressions
+################################################################################
+iSRS_BH <- function(param) {
+  if (!param %in% 1:4) stop("'param' must be from 1-4 when fun='BevertonHolt'.",call.=FALSE)
+  if(param==1){
+    expr <- expression(R==frac(aS,1+bS))
+  } else if (param==2) {
+    expr <- expression(R==frac(aS,1+a*~frac(S,R[p])))
+  } else if (param==3) {
+    expr <- expression(R==frac(S,tilde(a)+tilde(b)*S))
+  } else {
+    expr <- expression(R==frac(S,tilde(a)+frac(S,R[p])))
+  }
+  expr
+}
+
+iSRS_RICKER <- function(param) {
+  if (!param %in% 1:3) stop("'param' must be from 1-3 when fun='Ricker'.",call.=FALSE)
+  if(param==1){
+    expr <- expression(R==aSe^{-bS})
+  } else if (param==2) {
+    expr <- expression(R==Se^{tilde(a)-bS})
+  } else {
+    expr <- expression(R==aSe^{-a*~frac(S,R[p]*~e)})
+  }
+  expr
+}
+
+iSRS_SHEPHERD <- function() {
+  expression(R==frac(aS,1+(bS)^{c}))
+}
+
+iSRS_SL <- function() {
+  expression(R==aS^{c}*e^{-bS})
+}
